@@ -856,6 +856,7 @@ async def create_payload(
     return_on_complete: bool = True,
     timeout: int = None,
     custom_return_attributes: str = None,
+    include_all_commands: bool = False,
 ) -> dict:
     """
     This tasks Mythic to create a new payload based on the supplied parameters. If `return_on_complete` is false, then this will return immediately after issuing the task to Mythic.
@@ -1743,6 +1744,29 @@ async def update_operation(
         )
 
 
+async def update_current_operation_for_user(
+    mythic: mythic_classes.Mythic, operator_id: int, operation_id: int
+):
+    """
+    Sets the specified operation as current for the specified user.
+    """
+    query = """
+    mutation updateCurrentOpertionMutation($operator_id: Int!, $operation_id: Int!) {
+        updateCurrentOperation(user_id: $operator_id, operation_id: $operation_id) {
+            status
+            error
+            operation_id
+        }
+    }
+    """
+    results = await mythic_utilities.graphql_post(
+        mythic=mythic,
+        query=query,
+        variables={"operator_id": operator_id, "operation_id": operation_id},
+    )
+    return results["updateCurrentOperation"]
+
+
 # ############ Process Functions ##############
 
 
